@@ -17,29 +17,28 @@
  * Author: Dario Di Nucci <linkin88mail@gmail.com>
  */
 
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 
 const MapView = imports.mapView;
 const ShapeLayer = imports.shapeLayer;
 const Utils = imports.utils;
 
-var ShapeLayerRow = new Lang.Class({
-    Name: 'ShapeLayerRow',
-    Extends: Gtk.ListBoxRow,
+var ShapeLayerRow = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/shape-layer-row.ui',
     Children: ['closeButton'],
-    InternalChildren: ['layerLabel', 'visibleButton'],
+    InternalChildren: ['layerLabel', 'visibleButton']
+}, class ShapeLayerRow extends Gtk.ListBoxRow {
 
-    _init: function(params) {
+    _init(params) {
         this.shapeLayer = params.shapeLayer;
         delete params.shapeLayer;
 
-        this.parent(params);
+        super._init(params);
 
         this._layerLabel.label = this.shapeLayer.getName();
         this._layerLabel.tooltip_text = this.shapeLayer.file.get_parse_name();
-        this._visibleButton.connect('clicked', (function() {
+        this._visibleButton.connect('clicked', () => {
             let image = this._visibleButton.get_child();
 
             this.shapeLayer.visible = !this.shapeLayer.visible;
@@ -48,24 +47,23 @@ var ShapeLayerRow = new Lang.Class({
                 image.icon_name = 'layer-visible-symbolic';
             else
                 image.icon_name = 'layer-not-visible-symbolic';
-        }).bind(this));
+        });
     }
 });
 
-var LayersPopover = new Lang.Class({
-    Name: 'LayersPopover',
-    Extends: Gtk.Popover,
+var LayersPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/layers-popover.ui',
     InternalChildren: [ 'streetLayerButton',
                         'aerialLayerButton',
                         'layersListBox',
-                        'loadLayerButton' ],
+                        'loadLayerButton' ]
+}, class LayersPopover extends Gtk.Popover {
 
-    _init: function(params) {
+    _init(params) {
         this._mapView = params.mapView;
         delete params.mapView;
 
-        this.parent({ width_request: 200,
+        super._init({ width_request: 200,
                       no_show_all: true,
                       transitions_enabled: false,
                       visible: false });
@@ -75,42 +73,42 @@ var LayersPopover = new Lang.Class({
         this.get_style_context().add_class('maps-popover');
 
         this._layersListBox.bind_model(this._mapView.shapeLayerStore,
-                                         this._listBoxCreateWidget.bind(this));
-        this._layersListBox.connect('row-activated', (function(lb, row) {
+                                       this._listBoxCreateWidget.bind(this));
+        this._layersListBox.connect('row-activated', (lb, row) => {
             this._mapView.gotoBBox(row.shapeLayer.bbox);
-        }).bind(this));
+        });
 
-        this._layersListBox.set_header_func(function(row, before) {
+        this._layersListBox.set_header_func((row, before) => {
             let header = before ? new Gtk.Separator() : null;
             row.set_header(header);
         });
 
-        this._streetLayerButton.connect('clicked', (function () {
+        this._streetLayerButton.connect('clicked', () => {
             this._mapView.setMapType(MapView.MapType.STREET);
-        }).bind(this));
+        });
 
-        this._aerialLayerButton.connect('clicked', (function () {
+        this._aerialLayerButton.connect('clicked', () => {
             this._mapView.setMapType(MapView.MapType.AERIAL);
-        }).bind(this));
-    },
+        });
+    }
 
-    setMapType: function(mapType) {
+    setMapType(mapType) {
         if (mapType === MapView.MapType.STREET)
             this._streetLayerButton.active = true;
         else if (mapType === MapView.MapType.AERIAL)
             this._aerialLayerButton.active = true;
-    },
+    }
 
-    _onRemoveClicked: function(row, button) {
+    _onRemoveClicked(row) {
         this._mapView.removeShapeLayer(row.shapeLayer);
         if (this._layersListBox.get_children().length <= 0)
             this._layersListBox.hide();
-    },
+    }
 
-    _listBoxCreateWidget: function(shapeLayer) {
+    _listBoxCreateWidget(shapeLayer) {
         let row = new ShapeLayerRow({ shapeLayer: shapeLayer });
         row.closeButton.connect('clicked',
-                                this._onRemoveClicked.bind(this, row));
+                                () => this._onRemoveClicked(row));
         this._layersListBox.show();
         return row;
     }
