@@ -20,12 +20,13 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  */
 
+const _ = imports.gettext.gettext;
+
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -48,34 +49,32 @@ const _CONFIGURE_ID_TIMEOUT = 100; // msecs
 const _WINDOW_MIN_WIDTH = 600;
 const _WINDOW_MIN_HEIGHT = 500;
 
-var ShapeLayerFileChooser = new Lang.Class({
-    Name: 'ShapeLayerFileChooser',
-    Extends: Gtk.FileChooserNative,
-    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui',
+var ShapeLayerFileChooser = GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui'
+}, class ShapeLayerFileChooser extends Gtk.FileChooserNative {
 
-    _init: function(params) {
-        this.parent(params);
+    _init(params) {
+        super._init(params);
         let allFilter = new Gtk.FileFilter();
         allFilter.set_name(_("All Layer Files"));
         this.add_filter(allFilter);
         this.set_filter(allFilter);
+        this.title = _("Open Shape Layer");
 
-        ShapeLayer.SUPPORTED_TYPES.forEach((function(layerClass) {
+        ShapeLayer.SUPPORTED_TYPES.forEach((layerClass) => {
             let filter = new Gtk.FileFilter();
-            [filter, allFilter].forEach(function(f) {
-                layerClass.mimeTypes.forEach(function(type) {
+            [filter, allFilter].forEach((f) => {
+                layerClass.mimeTypes.forEach((type) => {
                     f.add_mime_type(type);
                 });
             });
             filter.set_name(layerClass.displayName);
             this.add_filter(filter);
-        }).bind(this));
+        });
     }
 });
 
-var MainWindow = new Lang.Class({
-    Name: 'MainWindow',
-    Extends: Gtk.ApplicationWindow,
+var MainWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/main-window.ui',
     InternalChildren: [ 'headerBar',
                         'grid',
@@ -87,17 +86,18 @@ var MainWindow = new Lang.Class({
                         'favoritesButton',
                         'printRouteButton',
                         'zoomInButton',
-                        'zoomOutButton' ],
+                        'zoomOutButton' ]
+}, class MainWindow extends Gtk.ApplicationWindow {
 
     get mapView() {
         return this._mapView;
-    },
+    }
 
-    _init: function(params) {
+    _init(params) {
         this._overlay = params.overlay;
         delete params.overlay;
 
-        this.parent(params);
+        super._init(params);
 
         this._configureId = 0;
 
@@ -135,9 +135,9 @@ var MainWindow = new Lang.Class({
         this._grid.attach(this._sidebar, 1, 0, 1, 1);
 
         this._grid.show_all();
-    },
+    }
 
-    _createPlaceEntry: function() {
+    _createPlaceEntry() {
         let placeEntry = new PlaceEntry.PlaceEntry({ mapView: this._mapView,
                                                      visible: true,
                                                      margin_start: 35,
@@ -146,27 +146,22 @@ var MainWindow = new Lang.Class({
                                                      loupe: true,
                                                      matchRoute: true
                                                    });
-        placeEntry.connect('notify::place', (function() {
+        placeEntry.connect('notify::place', () => {
             if (placeEntry.place) {
                 this._mapView.showPlace(placeEntry.place, true);
             }
-        }).bind(this));
+        });
 
         let popover = placeEntry.popover;
-        popover.connect('selected', (function() {
-            this._mapView.grab_focus();
-        }).bind(this));
-        this._mapView.view.connect('button-press-event', (function () {
-            popover.hide();
-        }));
+        popover.connect('selected', () => this._mapView.grab_focus());
+        this._mapView.view.connect('button-press-event', () => popover.hide());
         return placeEntry;
-    },
+    }
 
-    _createSidebar: function() {
+    _createSidebar() {
         let sidebar = new Sidebar.Sidebar(this._mapView);
 
-        Application.routeQuery.connect('notify',
-                                       this._setRevealSidebar.bind(this, true));
+        Application.routeQuery.connect('notify', () => this._setRevealSidebar(true));
         this._toggleSidebarButton.bind_property('active',
                                                 this._mapView, 'routingOpen',
                                                 GObject.BindingFlags.BIDIRECTIONAL);
@@ -174,110 +169,108 @@ var MainWindow = new Lang.Class({
                                        sidebar, 'visible',
                                        GObject.BindingFlags.DEFAULT);
         return sidebar;
-    },
+    }
 
-    _initDND: function() {
+    _initDND() {
         this.drag_dest_set(Gtk.DestDefaults.DROP, null, 0);
         this.drag_dest_add_uri_targets();
 
-        this.connect('drag-motion', (function(widget, ctx, x, y, time) {
+        this.connect('drag-motion', (widget, ctx, x, y, time) => {
             Gdk.drag_status(ctx, Gdk.DragAction.COPY, time);
             return true;
-        }).bind(this));
+        });
 
-        this.connect('drag-data-received', (function(widget, ctx, x, y, data, info, time) {
+        this.connect('drag-data-received', (widget, ctx, x, y, data, info, time) => {
             let files = data.get_uris().map(Gio.file_new_for_uri);
             if (this._mapView.openShapeLayers(files))
                 Gtk.drag_finish(ctx, true, false, time);
             else
                 Gtk.drag_finish(ctx, false, false, time);
-        }).bind(this));
-    },
+        });
+    }
 
-    _initActions: function() {
+    _initActions() {
         Utils.addActions(this, {
             'close': {
-                onActivate: this.close.bind(this)
+                onActivate: () => this.close()
             },
             'about': {
-                onActivate: this._onAboutActivate.bind(this)
+                onActivate: () => this._onAboutActivate()
             },
             'map-type-menu': {
                 state: ['b', false],
-                onActivate: this._onMapTypeMenuActivate.bind(this)
+                onActivate: () => this._onMapTypeMenuActivate()
             },
             'switch-to-street-view': {
                 accels: ['<Primary>1', '<Primary>KP_1'],
-                onActivate: this._onStreetViewActivate.bind(this)
+                onActivate: () => this._onStreetViewActivate()
             },
             'switch-to-aearial-view': {
                 accels: ['<Primary>2', '<Primary>KP_2'],
-                onActivate: this._onAerialViewActivate.bind(this)
+                onActivate: () => this._onAerialViewActivate()
             },
             'goto-user-location': {
                 accels: ['<Primary>L'],
-                onActivate: this._onGotoUserLocationActivate.bind(this)
+                onActivate: () => this._onGotoUserLocationActivate()
             },
             'toggle-sidebar': {
                 accels: ['<Primary>D'],
                 state: ['b', false],
-                onChangeState: this._onToggleSidebarChangeState.bind(this)
+                onChangeState: (a, v) => this._onToggleSidebarChangeState(a, v)
             },
             'zoom-in': {
                 accels: ['plus', '<Primary>plus', 'KP_Add', '<Primary>KP_Add', 'equal', '<Primary>equal'],
-                onActivate: this._mapView.view.zoom_in.bind(this._mapView.view)
+                onActivate: () => this._mapView.view.zoom_in()
             },
             'zoom-out': {
                 accels: ['minus', '<Primary>minus', 'KP_Subtract', '<Primary>KP_Subtract'],
-                onActivate:  this._mapView.view.zoom_out.bind(this._mapView.view)
+                onActivate:  () => this._mapView.view.zoom_out()
             },
             'toggle-scale': {
                 accels: ['<Primary>S'],
-                onActivate:  this._mapView.toggleScale.bind(this._mapView)
+                onActivate:  () => this._mapView.toggleScale()
             },
             'find': {
                 accels: ['<Primary>F'],
-                onActivate: this._placeEntry.grab_focus.bind(this._placeEntry)
+                onActivate: () => this._placeEntry.grab_focus()
             },
             'print-route': {
                 accels: ['<Primary>P'],
-                onActivate: this._printRouteActivate.bind(this)
+                onActivate: () => this._printRouteActivate()
             },
             'open-shape-layer': {
                 accels: ['<Primary>O'],
-                onActivate: this._onOpenShapeLayer.bind(this)
+                onActivate: () => this._onOpenShapeLayer()
             }
         });
-    },
+    }
 
-    _initSignals: function() {
+    _initSignals() {
         this.connect('delete-event', this._quit.bind(this));
         this.connect('configure-event',
                      this._onConfigureEvent.bind(this));
 
         this.connect('window-state-event',
                      this._onWindowStateEvent.bind(this));
-        this._mapView.view.connect('button-press-event', (function() {
+        this._mapView.view.connect('button-press-event', () => {
             // Can not call something that will generate clutter events
             // from a clutter event-handler. So use an idle.
-            Mainloop.idle_add((function() {
-                this._mapView.grab_focus();
-            }).bind(this));
-        }).bind(this));
+            Mainloop.idle_add(() => this._mapView.grab_focus());
+        });
 
-        this.application.connect('notify::connected', (function() {
+        this.application.connect('notify::connected', () => {
             if (this.application.connected || this.application.local_tile_path)
                 this._mainStack.visible_child = this._overlay;
             else
                 this._mainStack.visible_child = this._noNetworkView;
-        }).bind(this));
+        });
 
         /*
          * If the currently focused widget is an entry then we will
          * hijack the key-press to the main window and make sure that
          * they reach the entry before they can be swallowed as accelerator.
          */
-        this.connect('key-press-event', (function(window, event) {
+        this.connect('key-press-event', (window, event) => {
             let focusWidget = window.get_focus();
             let keyval = event.get_keyval()[1];
             let keys = [Gdk.KEY_plus, Gdk.KEY_KP_Add,
@@ -304,7 +297,7 @@ var MainWindow = new Lang.Class({
                 return focusWidget.event(event);
 
             return false;
-        }).bind(this));
+        });
 
         this._mapView.view.connect('notify::zoom-level',
                                    this._updateZoomButtonsSensitivity.bind(this));
@@ -312,9 +305,9 @@ var MainWindow = new Lang.Class({
                                    this._updateZoomButtonsSensitivity.bind(this));
         this._mapView.view.connect('notify::min-zoom-level',
                                    this._updateZoomButtonsSensitivity.bind(this));
-    },
+    }
 
-    _updateZoomButtonsSensitivity: function() {
+    _updateZoomButtonsSensitivity() {
         let zoomLevel = this._mapView.view.zoom_level;
         let maxZoomLevel = this._mapView.view.max_zoom_level;
         let minZoomLevel = this._mapView.view.min_zoom_level;
@@ -328,32 +321,32 @@ var MainWindow = new Lang.Class({
             this._zoomOutButton.set_sensitive(false);
         else
             this._zoomOutButton.set_sensitive(true);
-    },
+    }
 
-    _updateLocationSensitivity: function() {
+    _updateLocationSensitivity() {
         let sensitive = (Application.geoclue.state !== Geoclue.State.INITIAL &&
                          (this.application.connected ||
                           this.application.local_tile_path));
 
         this._gotoUserLocationButton.sensitive = sensitive;
-    },
+    }
 
-    _initHeaderbar: function() {
+    _initHeaderbar() {
         this._placeEntry = this._createPlaceEntry();
         this._headerBar.custom_title = this._placeEntry;
 
         let favoritesPopover = this._favoritesButton.popover;
         this._favoritesButton.sensitive = favoritesPopover.rows > 0;
-        favoritesPopover.connect('notify::rows', (function() {
+        favoritesPopover.connect('notify::rows', () => {
             this._favoritesButton.sensitive = favoritesPopover.rows > 0;
-        }).bind(this));
+        });
 
         this._mapView.bind_property('routeShowing', this._printRouteButton,
                                     'visible', GObject.BindingFlags.DEFAULT);
 
         Application.geoclue.connect('notify::state',
                                     this._updateLocationSensitivity.bind(this));
-        this.application.connect('notify::connected', (function() {
+        this.application.connect('notify::connected', () => {
             let app = this.application;
 
             this._updateLocationSensitivity();
@@ -363,10 +356,10 @@ var MainWindow = new Lang.Class({
                                                favoritesPopover.rows > 0);
             this._placeEntry.sensitive = app.connected;
             this._printRouteButton.sensitive = app.connected;
-        }).bind(this));
-    },
+        });
+    }
 
-    _saveWindowGeometry: function() {
+    _saveWindowGeometry() {
         let window = this.get_window();
         let state = window.get_state();
 
@@ -379,9 +372,9 @@ var MainWindow = new Lang.Class({
 
         let position = this.get_position();
         Application.settings.set('window-position', position);
-    },
+    }
 
-    _restoreWindowGeometry: function() {
+    _restoreWindowGeometry() {
         let size = Application.settings.get('window-size');
         if (size.length === 2) {
             let [width, height] = size;
@@ -397,22 +390,22 @@ var MainWindow = new Lang.Class({
 
         if (Application.settings.get('window-maximized'))
             this.maximize();
-    },
+    }
 
-    _onConfigureEvent: function(widget, event) {
+    _onConfigureEvent(widget, event) {
         if (this._configureId !== 0) {
             Mainloop.source_remove(this._configureId);
             this._configureId = 0;
         }
 
-        this._configureId = Mainloop.timeout_add(_CONFIGURE_ID_TIMEOUT, (function() {
+        this._configureId = Mainloop.timeout_add(_CONFIGURE_ID_TIMEOUT, () => {
             this._saveWindowGeometry();
             this._configureId = 0;
             return false;
-        }).bind(this));
-    },
+        });
+    }
 
-    _onWindowStateEvent: function(widget, event) {
+    _onWindowStateEvent(widget, event) {
         let window = widget.get_window();
         let state = window.get_state();
 
@@ -421,9 +414,9 @@ var MainWindow = new Lang.Class({
 
         let maximized = (state & Gdk.WindowState.MAXIMIZED);
         Application.settings.set('window-maximized', maximized);
-    },
+    }
 
-    _quit: function() {
+    _quit() {
         // remove configure event handler if still there
         if (this._configureId !== 0) {
             Mainloop.source_remove(this._configureId);
@@ -434,18 +427,18 @@ var MainWindow = new Lang.Class({
         this._saveWindowGeometry();
 
         return false;
-    },
+    }
 
-    _getLocationServiceNotification: function() {
+    _getLocationServiceNotification() {
         if (!this._locationServiceNotification) {
             this._locationServiceNotification =
                 new LocationServiceNotification.LocationServiceNotification();
         }
 
         return this._locationServiceNotification;
-    },
+    }
 
-    _onGotoUserLocationActivate: function() {
+    _onGotoUserLocationActivate() {
         let message;
 
         if (Application.geoclue.state === Geoclue.State.ON) {
@@ -453,7 +446,7 @@ var MainWindow = new Lang.Class({
             return;
         }
 
-        Application.geoclue.start((function() {
+        Application.geoclue.start(() => {
             switch(Application.geoclue.state) {
             case Geoclue.State.FAILED:
                 message = _("Failed to connect to location service");
@@ -469,43 +462,43 @@ var MainWindow = new Lang.Class({
                 this._mapView.gotoUserLocation(true);
                 break;
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _printRouteActivate: function() {
+    _printRouteActivate() {
         if (this._mapView.routeShowing) {
             let operation = new PrintOperation.PrintOperation({ mainWindow: this });
         }
-    },
+    }
 
-    _onMapTypeMenuActivate: function(action) {
+    _onMapTypeMenuActivate(action) {
         let state = action.get_state().get_boolean();
         action.set_state(GLib.Variant.new('b', !state));
-    },
+    }
 
-    _onStreetViewActivate: function() {
+    _onStreetViewActivate() {
         this._mapView.setMapType(MapView.MapType.STREET);
         this.layersPopover.setMapType(MapView.MapType.STREET);
-    },
+    }
 
-    _onAerialViewActivate: function() {
+    _onAerialViewActivate() {
         this._mapView.setMapType(MapView.MapType.AERIAL);
         this.layersPopover.setMapType(MapView.MapType.AERIAL);
-    },
+    }
 
-    _onToggleSidebarChangeState: function(action, variant) {
+    _onToggleSidebarChangeState(action, variant) {
         action.set_state(variant);
 
         let reveal = variant.get_boolean();
         this._sidebar.set_reveal_child(reveal);
-    },
+    }
 
-    _setRevealSidebar: function(value) {
+    _setRevealSidebar(value) {
         let action = this.lookup_action('toggle-sidebar');
         action.change_state(GLib.Variant.new_boolean(value));
-    },
+    }
 
-    _onAboutActivate: function() {
+    _onAboutActivate() {
         let aboutDialog = new Gtk.AboutDialog({
             artists: [ 'Jakub Steiner <jimmac@gmail.com>',
                        'Andreas Nilsson <nisses.mail@home.se>' ],
@@ -541,12 +534,10 @@ var MainWindow = new Lang.Class({
         copyrightLabel.show();
 
         aboutDialog.show();
-        aboutDialog.connect('response', (function() {
-            aboutDialog.destroy();
-        }));
-    },
+        aboutDialog.connect('response', () => aboutDialog.destroy());
+    }
 
-    _getAttribution: function() {
+    _getAttribution() {
         let tileProviderInfo = Service.getService().tileProviderInfo;
         let attribution = _("Map data by %s and contributors").format('<a href="https://www.openstreetmap.org">OpenStreetMap</a>');
 
@@ -568,36 +559,34 @@ var MainWindow = new Lang.Class({
         }
 
         return attribution;
-    },
+    }
 
-    _onOpenShapeLayer: function() {
+    _onOpenShapeLayer() {
         let fileChooser = new ShapeLayerFileChooser({
             transient_for: this,
         });
 
-        fileChooser.connect('response', (function(widget, response) {
+        fileChooser.connect('response', (widget, response) => {
             if (response === Gtk.ResponseType.ACCEPT) {
                 this._mapView.openShapeLayers(fileChooser.get_files());
                 this.layersPopover.popdown();
             }
             fileChooser.destroy();
-        }).bind(this));
+        });
         fileChooser.show();
-    },
+    }
 
-    markBusy: function() {
+    markBusy() {
         if (this._busySignalId !== 0)
             return;
 
         this._busy.show();
 
         let stage = this._mapView.view.get_stage();
-        this._busySignalId = stage.connect('captured-event', function() {
-            return true;
-        });
-    },
+        this._busySignalId = stage.connect('captured-event', () => true);
+    }
 
-    unmarkBusy: function() {
+    unmarkBusy() {
         this._busy.hide();
 
         let stage = this._mapView.view.get_stage();
